@@ -40,7 +40,7 @@
 class KFileItem;
 
 class KRQuery : public TQObject {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public:
